@@ -22,11 +22,11 @@ IO::Iron::IronWorker::Api - IronWorker API reference for Perl Client Libraries!
 
 =head1 VERSION
 
-Version 0.03
+Version 0.04
 
 =cut
 
-our $VERSION = '0.03';
+our $VERSION = '0.04';
 
 
 =head1 SYNOPSIS
@@ -176,7 +176,7 @@ sub IRONWORKER_LIST_TASKS {
 			'action_name'    => 'IRONWORKER_LIST_TASKS',
 			'href'           => '{Protocol}://{Host}:{Port}{Host Path Prefix}/projects/{Project ID}/tasks',
 			'action'         => 'GET',
-			'return'         => 'HASH',
+			'return'         => 'LIST:tasks',
 			'retry'          => 1,
 			'require_body'   => 0,
 			'paged'          => 1,
@@ -254,8 +254,6 @@ sub IRONWORKER_GET_INFO_ABOUT_A_TASK {
 
 =cut
 
-# TODO GET_A_TASKS_LOG requires more work ('return' => 'PLAIN_TEXT')!
-
 sub IRONWORKER_GET_A_TASKS_LOG {
 	return {
 			'action_name'    => 'IRONWORKER_GET_A_TASKS_LOG',
@@ -269,6 +267,25 @@ sub IRONWORKER_GET_A_TASKS_LOG {
 		}; # Return plain text, not JSON!
 }
 
+=head3 IRONWORKER_CANCEL_A_TASK
+
+/projects/{Project ID}/tasks/{Task ID}/cancel
+
+=cut
+
+sub IRONWORKER_CANCEL_A_TASK {
+	return {
+			'action_name'    => 'IRONWORKER_CANCEL_A_TASK',
+			'href'           => '{Protocol}://{Host}:{Port}{Host Path Prefix}/projects/{Project ID}/tasks/{Task ID}/cancel',
+			'action'         => 'POST',
+			'return'         => 'MESSAGE',
+			'retry'          => 1,
+			'require_body'   => 0,
+			'url_escape'     => { '{Project ID}' => 1, '{Task ID}' => 1,  },
+			'log_message'    => '(project={Project ID}, task={Task ID}). Cancelled a task.',
+		};
+}
+
 =head3 IRONWORKER_SET_A_TASKS_PROGRESS
 
 /projects/{Project ID}/tasks/{Task ID}/progress
@@ -305,7 +322,7 @@ sub IRONWORKER_RETRY_A_TASK {
 			'require_body'   => 1,
 			'request_fields' => { 'delay' => 1 },
 			'url_escape'     => { '{Project ID}' => 1, '{Task ID}' => 1 },
-			'log_message'    => '(project={Project ID}, code={Task ID}). Set task\'s progress.',
+			'log_message'    => '(project={Project ID}, code={Task ID}, delay={delay}). Task queued for retry.',
 		};
 }
 
@@ -322,7 +339,7 @@ sub IRONWORKER_LIST_SCHEDULED_TASKS {
 			'action_name'    => 'IRONWORKER_LIST_SCHEDULED_TASKS',
 			'href'           => '{Protocol}://{Host}:{Port}{Host Path Prefix}/projects/{Project ID}/schedules',
 			'action'         => 'GET',
-			'return'         => 'HASH',
+			'return'         => 'LIST:schedules',
 			'retry'          => 1,
 			'require_body'   => 0,
 			'paged'          => 1,
@@ -341,12 +358,11 @@ sub IRONWORKER_LIST_SCHEDULED_TASKS {
 sub IRONWORKER_SCHEDULE_A_TASK {
 	return {
 			'action_name'    => 'IRONWORKER_SCHEDULE_A_TASK',
-			'href'           => '{Protocol}://{Host}:{Port}{Host Path Prefix}/projects/{Project ID}/tasks',
+			'href'           => '{Protocol}://{Host}:{Port}{Host Path Prefix}/projects/{Project ID}/schedules',
 			'action'         => 'POST',
 			'return'         => 'HASH',
 			'retry'          => 1,
 			'require_body'   => 1,
-			#'request_fields' => { 'code_name' => 1, 'payload' => 1, 'run_every' => 1, 'end_at' => 1, 'run_times' => 1, 'priority' => 1, 'start_at' => 1 },
 			'request_fields' => { 'schedules' => 1 },
 			'url_escape'     => { '{Project ID}' => 1 },
 			'log_message'    => '(project={Project ID}). Scheduled task.',
@@ -385,9 +401,9 @@ sub IRONWORKER_CANCEL_A_SCHEDULED_TASK {
 			'action'         => 'POST',
 			'return'         => 'MESSAGE',
 			'retry'          => 1,
-			'require_body'   => 1,
+			'require_body'   => 0,
 			'url_escape'     => { '{Project ID}' => 1, '{Schedule ID}' => 1,  },
-			'log_message'    => '(project={Project ID}, schedule={Schedule ID}). Got info about scheduled task.',
+			'log_message'    => '(project={Project ID}, schedule={Schedule ID}). Canceled scheduled task.',
 		};
 }
 
